=============================
``psyclone.core.access_type``
=============================

.. automodule:: psyclone.core.access_type

   .. contents::
      :local:

.. currentmodule:: psyclone.core.access_type


Classes
=======

- :py:class:`AccessType`:
  A simple enum-class for the various valid access types.


.. autoclass:: AccessType
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: AccessType
      :parts: 1
